% Created 2010-April-15
% Written by Peter J. Schmid
% Matlab script for processing EDF cylinder-bundle data 

%============================================
%   Analysis Module for DMD Analysis
%============================================

  clear all;
  close all;

  load('VVV.mat');

  %...time interval between the snapshots
  dt   = 0.004;
  xmin = 0.501243; xmax = 40.859397;
  ymin = 0.501243; ymax = 32.580801;

  nx = n; ny = m;

  %...set up the coordinate axes and spatial resolution
  xcoord = linspace(xmin,xmax,n);
  ycoord = linspace(ymin,ymax,m);
  dx     = xcoord(2)-xcoord(1);
  dy     = ycoord(2)-ycoord(1);

   %...perform the DMD decomposition
   nsnap = size(VVV,2);
   %...create the left- and right-shifted matrices
   Vleft  = VVV(:,1:nsnap-1);
   Vright = VVV(:,2:nsnap);

   %...compute the SVD
   [UU,SS,VV] = svd(Vleft,0);
   SD  = diag(SS);

   %...various cut-off options
   %...(1) 
   tol = max(nsnap-1,nx*ny)*eps(max(SD(1)));
   r   = sum(SD>tol);
   %...(2) compute a cumulative vector of contained coherence
   rcut = cumsum(SD)/sum(SD);
   % cut off when 95 % or 99 % of cumulative coherence is reached
   r = fix(max(min(find(rcut>0.99)),10));
   %...(3) take all available snapshots (no cutoff) 
   r = nsnap-1;
   fprintf(' %i modes are being used \n',r);

   %...build the system matrix L
   S = diag(ones(r,1)./SD(1:r));
   L = UU(:,1:r)'*Vright*VV(:,1:r)*S;

   %...output the expansion basis
   UUU = UU(:,1:r);
   Sig = diag(SS(1:r,1:r));

   Mih1 = UU(:,1:r)'*Vright;
   Mih2 = VV(:,1:r);
   Mih3 = SD(1:r);

   clear L S UU SD SS Sig UU UUU VV VVV Vleft Vright dirdata dt dx dy m n ...
       nsnap nx ny r rcut tol xcoord xmax xmin ycoord ymax ymin
   save('MMM.mat');
